@@ -1,10 +1,10 @@
 import branca.colormap as colormap
 import branca.element as element
 
-from ._version import get_versions
-
-__version__ = get_versions()['version']
-del get_versions
+try:
+    from ._version import __version__
+except ImportError:
+    __version__ = "unknown"
 
 
 __all__ = [
