@@ -84,13 +84,18 @@ class ColorMap(MacroElement):
         self.caption = caption
         self.index = [vmin, vmax]
         self.max_labels = max_labels
+        self.tick_labels = None
+
+        self.width = 450
+        self.height = 40
 
     def render(self, **kwargs):
         """Renders the HTML representation of the element."""
         self.color_domain = [self.vmin + (self.vmax-self.vmin) * k/499. for
                              k in range(500)]
         self.color_range = [self.__call__(x) for x in self.color_domain]
-        self.tick_labels = legend_scaler(self.index, self.max_labels)
+        if self.tick_labels is None:
+            self.tick_labels = legend_scaler(self.index, self.max_labels)
 
         super(ColorMap, self).render(**kwargs)
 
@@ -141,21 +146,52 @@ class ColorMap(MacroElement):
         return self.rgba_hex_str(x)
 
     def _repr_html_(self):
+        """Display the colormap in a Jupyter Notebook.
+
+        Does not support all the class arguments.
+
+        """
+        nb_ticks = 7
+        delta_x = math.floor(self.width / (nb_ticks - 1))
+        x_ticks = [(i) * delta_x for i in range(0, nb_ticks)]
+        delta_val = delta_x * (self.vmax - self.vmin) / self.width
+        val_ticks = [round(self.vmin + (i) * delta_val, 1) for i in range(0, nb_ticks)]
+
         return (
-            '<svg height="50" width="500">' +
-            ''.join(
-                [('<line x1="{i}" y1="0" x2="{i}" '
-                  'y2="20" style="stroke:{color};stroke-width:3;" />').format(
-                      i=i*1,
-                      color=self.rgba_hex_str(
-                          self.vmin +
-                          (self.vmax-self.vmin)*i/499.)
-                  )
-                 for i in range(500)]) +
-            '<text x="0" y="35">{}</text>'.format(self.vmin) +
-            '<text x="500" y="35" style="text-anchor:end;">{}</text>'.format(
-                self.vmax) +
-            '</svg>')
+            '<svg height="40" width="{}">'.format(self.width)
+            + "".join(
+                [
+                    (
+                        '<line x1="{i}" y1="15" x2="{i}" '
+                        'y2="27" style="stroke:{color};stroke-width:2;" />'
+                    ).format(
+                        i=i * 1,
+                        color=self.rgba_hex_str(
+                            self.vmin + (self.vmax - self.vmin) * i / (self.width - 1)
+                        ),
+                    )
+                    for i in range(self.width)
+                ]
+            )
+            + '<text x="0" y="38" style="text-anchor:start; font-size:11px; font:Arial">{}</text>'.format(
+                self.vmin
+            )
+            + "".join(
+                [
+                    (
+                        '<text x="{}" y="38"; style="text-anchor:middle; font-size:11px; font:Arial">{}</text>'
+                    ).format(x_ticks[i], val_ticks[i])
+                    for i in range(1, nb_ticks - 1)
+                ]
+            )
+            + '<text x="{}" y="38" style="text-anchor:end; font-size:11px; font:Arial">{}</text>'.format(
+                self.width, self.vmax
+            )
+            + '<text x="0" y="12" style="font-size:11px; font:Arial">{}</text>'.format(
+                self.caption
+            )
+            + "</svg>"
+        )
 
 
 class LinearColormap(ColorMap):
@@ -185,11 +221,13 @@ class LinearColormap(ColorMap):
         The maximal value for the colormap.
         Values higher than `vmax` will be bound directly to `colors[-1]`.
     max_labels : int, default 10
-        Maximum number of legend tick labels"""
-
-    def __init__(self, colors, index=None, vmin=0., vmax=1., caption='', max_labels=10):
+        Maximum number of legend tick labels
+    tick_labels: list of floats, default None
+        If given, used as the positions of ticks."""
+    def __init__(self, colors, index=None, vmin=0., vmax=1., caption='', max_labels=10, tick_labels=None):
         super(LinearColormap, self).__init__(vmin=vmin, vmax=vmax,
                                              caption=caption, max_labels=max_labels)
+        self.tick_labels = tick_labels
 
         n = len(colors)
         if n < 2:
@@ -332,7 +370,7 @@ class LinearColormap(ColorMap):
         caption = self.caption
 
         return StepColormap(colors, index=index, vmin=index[0], vmax=index[-1], caption=caption,
-                            max_labels=max_labels)
+                            max_labels=max_labels, tick_labels=self.tick_labels)
 
     def scale(self, vmin=0., vmax=1., max_labels=10):
         """Transforms the colorscale so that the minimal and maximal values
@@ -375,11 +413,13 @@ class StepColormap(ColorMap):
         Values higher than `vmax` will be bound directly to `colors[-1]`.
     max_labels : int, default 10
         Maximum number of legend tick labels
-
+    tick_labels: list of floats, default None
+        If given, used as the positions of ticks.
     """
-    def __init__(self, colors, index=None, vmin=0., vmax=1., caption='', max_labels=10):
+    def __init__(self, colors, index=None, vmin=0., vmax=1., caption='', max_labels=10, tick_labels=None):
         super(StepColormap, self).__init__(vmin=vmin, vmax=vmax,
                                            caption=caption, max_labels=max_labels)
+        self.tick_labels = tick_labels
 
         n = len(colors)
         if n < 1:
